==> kyt-1.2.5.tgz: package/lib/actions/dev.js <==
"use strict";

// Command to run development server
var shell = require('shelljs');

var WebpackDevServer = require('webpack-dev-server');

var logger = require('kyt-utils/logger');

var _require = require('kyt-utils/paths')(),
    buildPath = _require.buildPath;

var buildConfigs = require('../utils/buildConfigs');

var webpackCompiler = require('../utils/webpackCompiler');

var setPorts = require('../utils/setPorts'); // Capture any --inspect or --inspect-brk flags (with optional values) so that we
// can pass them when we invoke nodejs


process.env.INSPECT_BRK = process.argv.find(function (arg) {
  return arg.match(/--inspect-brk(=|$)/);
}) || '';
process.env.INSPECT = process.argv.find(function (arg) {
  return arg.match(/--inspect(=|$)/);
}) || '';

module.exports = function (config) {
  logger.start('Starting development build...'); // Kill the server on exit.

  process.on('SIGINT', process.exit);

  var _buildConfigs = buildConfigs(config),
      clientConfig = _buildConfigs.clientConfig,
      serverConfig = _buildConfigs.serverConfig;

  function main() {
    var port = parseInt(process.env.PORT_DEV, 10);

    if (!port) {
      throw new Error('Port is not available.');
    }

    var clientCompiler;
    var serverCompiler; // Clean the build directory.

    if (shell.test('-d', buildPath) && shell.rm('-rf', buildPath).code === 0) {
      logger.task('Cleaned ./build');
    }

    if (config.hasClient) {
      // Compile Client Webpack Config
      clientCompiler = webpackCompiler(clientConfig);
    } // Compile Server Webpack Config


    if (config.hasServer) {
      serverCompiler = webpackCompiler(serverConfig);
    } // Instatiate a variable to track server watching


    var watching;

    var watchServer = function watchServer() {
      // If we've already started the server watcher, bail early.
      if (watching || !config.hasServer) {
        return;
      } // Otherwise, create a new watcher for our server code.


      watching = serverCompiler.watch({
        quiet: true,
        stats: 'none'
      }, // eslint-disable-next-line no-unused-vars
      function (stats) {});
    };

    if (config.hasClient) {
      // Start our server webpack instance in watch mode after assets compile
      clientCompiler.hooks.done.tap('kyt', function () {
        watchServer();
      }); // Create a new instance of Webpack-dev-server for our client assets.
      // This will actually run on a different port than the users app.

      var clientDevServer = new WebpackDevServer(clientCompiler, clientConfig.devServer); // Start Webpack-dev-server

      clientDevServer.listen(port, function (err) {
        if (err) {
          logger.error(err);
        }
      });
    } else {
      watchServer();
    }
  }

  return setPorts(config).then(main) // eslint-disable-next-line no-console
  ["catch"](console.error);
};

==> kyt-1.2.9.tgz: package/lib/actions/dev.js <==
"use strict";

// Command to run development server

var shell = require('shelljs');
var WebpackDevServer = require('webpack-dev-server');
var logger = require('kyt-utils/logger');
var _require = require('kyt-utils/paths')(),
  buildPath = _require.buildPath;
var buildConfigs = require('../utils/buildConfigs');
var webpackCompiler = require('../utils/webpackCompiler');
var setPorts = require('../utils/setPorts');

// Capture any --inspect or --inspect-brk flags (with optional values) so that we
// can pass them when we invoke nodejs
process.env.INSPECT_BRK = process.argv.find(function (arg) {
  return arg.match(/--inspect-brk(=|$)/);
}) || '';
process.env.INSPECT = process.argv.find(function (arg) {
  return arg.match(/--inspect(=|$)/);
}) || '';
module.exports = function (config) {
  logger.start('Starting development build...');

  // Kill the server on exit.
  process.on('SIGINT', process.exit);
  var _buildConfigs = buildConfigs(config),
    clientConfig = _buildConfigs.clientConfig,
    serverConfig = _buildConfigs.serverConfig;
  function main() {
    var port = parseInt(process.env.PORT_DEV, 10);
    if (!port) {
      throw new Error('Port is not available.');
    }
    var clientCompiler;
    var serverCompiler;

    // Clean the build directory.
    if (shell.test('-d', buildPath) && shell.rm('-rf', buildPath).code === 0) {
      logger.task('Cleaned ./build');
    }
    if (config.hasClient) {
      // Compile Client Webpack Config
      clientCompiler = webpackCompiler(clientConfig);
    }

    // Compile Server Webpack Config
    if (config.hasServer) {
      serverCompiler = webpackCompiler(serverConfig);
    }

    // Instatiate a variable to track server watching
    var watching;
    var watchServer = function watchServer() {
      // If we've already started the server watcher, bail early.
      if (watching || !config.hasServer) {
        return;
      }
      // Otherwise, create a new watcher for our server code.
      watching = serverCompiler.watch({
        quiet: true,
        stats: 'none'
      },
      // eslint-disable-next-line no-unused-vars
      function (stats) {});
    };
    if (config.hasClient) {
      // Start our server webpack instance in watch mode after assets compile
      clientCompiler.hooks.done.tap('kyt', function () {
        watchServer();
      });

      // Create a new instance of Webpack-dev-server for our client assets.
      // This will actually run on a different port than the users app.
      var clientDevServer = new WebpackDevServer(clientCompiler, clientConfig.devServer);

      // Start Webpack-dev-server
      clientDevServer.listen(port, function (err) {
        if (err) {
          logger.error(err);
        }
      });
    } else {
      watchServer();
    }
  }
  return setPorts(config).then(main)
  // eslint-disable-next-line no-console
  ["catch"](console.error);
};
